""":orphan:

Deprecated sub-package

"""
import warnings

warnings.warn(
    (
        "Package snek5000.assets will be removed on a later release. "
        "Use snek5000.resources instead."
    ),
    DeprecationWarning,
)
